@@ -854,6 +854,7 @@ LDAP *server_bind(const char *securitydir, char *host, int port, int security, c
   return server;
 }
 
+#if 0 /* NOT USED */
 /* rate is specified in seconds */
 static int get_topology_refresh_rate(AdmldapInfo admInfo) {
 
@@ -868,7 +869,7 @@ static int get_topology_refresh_rate(AdmldapInfo admInfo) {
 
   return rate;
 }
-
+#endif
 
 /* rate is specified in seconds */
 static int get_cgi_timeout_rate(AdmldapInfo admInfo) {
@@ -895,38 +896,58 @@ static int get_cgi_timeout_rate(AdmldapInfo admInfo) {
  * -1 = unknown error
  */
                   
-int server_status(char *host, int port) {
-  
-  PRHostEnt 	*hstruct; 
-  PRHostEnt   hent;
-  char        buf[PR_NETDB_BUF_SIZE];
+int
+server_status(char *host, int port)
+{
+  PRNetAddr   *netaddr = NULL;
   PRStatus    err;
-  
   PRFileDesc *req_socket= NULL;
-  int retcode;
-  PRNetAddr netAddr;
+  int retcode = 0;
 
-  if(!isdigit(host[0]))  {
-  err = PR_GetHostByName(host,
-        buf,
-        PR_NETDB_BUF_SIZE,
-        &hent);
-  if(err == PR_FAILURE)
-   return -1;
+  if (NULL == host) {
+    return -1;
   }
 
-  hstruct = &hent;
-  PR_InitializeNetAddr(PR_IpAddrNull, (PRUint16)port, &netAddr);
-  netAddr.inet.ip = *((PRUint32*)hstruct->h_addr_list[0]);
-
-  req_socket = PR_NewTCPSocket();
-  retcode = PR_Connect(req_socket, &netAddr, 10000);
-
-  if(retcode != 0)
-     return 0;
-  else
-     return 1;
+  netaddr = (PRNetAddr *)calloc(1, sizeof(PRNetAddr));
+  if (NULL == netaddr) {
+    rpt_err(APP_ERROR, "Failed to allocate PRNetAddr", NULL, NULL);
+    return -1;
+  }
+  err = PR_StringToNetAddr(host, netaddr);
+  if (PR_SUCCESS == err) {
+    PR_InitializeNetAddr(PR_IpAddrNull, (PRUint16)port, netaddr);
+  } else {
+    PRAddrInfo *infop = PR_GetAddrInfoByName(host,
+                            PR_AF_UNSPEC, (PR_AI_ADDRCONFIG|PR_AI_NOCANONNAME));
+    if (infop) {
+      void *iter = NULL;
+      memset( netaddr, 0, sizeof( PRNetAddr ));
+      /* need just one address */
+      iter = PR_EnumerateAddrInfo(iter, infop, (PRUint16)port, netaddr);
+      if (NULL == iter) {
+         rpt_err(APP_ERROR, "Failed to enumerate addrinfo", NULL, NULL);
+         retcode = -1;
+      }
+      PR_FreeAddrInfo(infop);
+    } else {
+      rpt_err(APP_ERROR, "Failed to get addrinfo", NULL, NULL);
+      retcode = -1;
+    }
+  }
 
+  if (retcode < 0) {
+    free(netaddr);
+    return retcode;
+  } else {
+    req_socket = PR_NewTCPSocket();
+    err = PR_Connect(req_socket, netaddr, 10000);
+    free(netaddr);
+    if (PR_SUCCESS == err) {
+      return 1;
+    } else {
+      return 0;
+    }
+  }
 }
 
 
@@ -981,7 +1002,7 @@ int output_topology(AdmldapInfo ldapInfo,
   }
 
 
-  fprintf(stdout, getResourceString(DBT_OUTPUT_TOPOLOGY_TABLE_HEADER));
+  fprintf(stdout, "%s", getResourceString(DBT_OUTPUT_TOPOLOGY_TABLE_HEADER));
 
   for(domain_entry = ldap_first_entry(server, domain_result);
       domain_entry != NULL;
@@ -1154,8 +1175,8 @@ int output_topology(AdmldapInfo ldapInfo,
 	      char *admin_url;
 	      char *server_host;
 	      int *server_port;
-	      int running;
-	      char *href;
+	      int running = 0;
+	      char *href = NULL;
 	      char *info_link;
 	      char *log_link;
 
@@ -1211,7 +1232,10 @@ int output_topology(AdmldapInfo ldapInfo,
 
 	        free((void *)dn_escaped);
 	        free((void *)val_escaped);
-	        PR_smprintf_free((char *)href);
+	        if (running == 1) {
+	          PR_smprintf_free((char *)href);
+	          href = NULL;
+	        }
 	        PR_smprintf_free((char *)info_link);
 	        PR_smprintf_free((char *)log_link);
 	      } else if(strstr(ldap_get_dn(server, sie_entry), "Directory")) {
@@ -1255,7 +1279,9 @@ int output_topology(AdmldapInfo ldapInfo,
 	        free((void *)dn_escaped);
 	        free((void *)val_escaped);
 	        free((void *)host_escaped);
-	        PR_smprintf_free((char *)href);
+	        if (href) {
+	          PR_smprintf_free((char *)href);
+	        }
 	        PR_smprintf_free((char *)info_link);
 	        PR_smprintf_free((char *)log_link);
 	        PR_smprintf_free((char *)repl_link);
@@ -1334,7 +1360,7 @@ int output_topology(AdmldapInfo ldapInfo,
 		PR_smprintf_free((char *)log_link);
 	      }
 
-	      fprintf(stdout, getResourceString(DBT_OUTPUT_TOPOLOGY_TABLE_FOOTER));
+	      fprintf(stdout, "%s", getResourceString(DBT_OUTPUT_TOPOLOGY_TABLE_FOOTER));
 
 	      util_ldap_value_free(vals);
 	    } else {
@@ -1563,7 +1589,7 @@ int main(int argc, char *argv[])
     m = getenv("REQUEST_METHOD");
 
 
-    fprintf(stdout, getResourceString(DBT_MAIN_CONTENT_TYPE));
+    fprintf(stdout, "%s", getResourceString(DBT_MAIN_CONTENT_TYPE));
 
     if(m && !strcmp(m, "GET")) {
 
@@ -1587,15 +1613,15 @@ int main(int argc, char *argv[])
 	   * Load the frames.
 	   */
 
-	  fprintf(stdout, getResourceString(DBT_MAIN_FRAME_HEADER));
+	  fprintf(stdout, "%s", getResourceString(DBT_MAIN_FRAME_HEADER));
 	  fprintf(stdout, "%s", view ? viewparam : "");
-	  fprintf(stdout, getResourceString(DBT_MAIN_FRAME_FOOTER));
+	  fprintf(stdout, "%s", getResourceString(DBT_MAIN_FRAME_FOOTER));
 
        }
        else if(operation && !strcmp(operation, "empty")) {
 
 	 /* Message frame */
-	 fprintf(stdout, getResourceString(DBT_MAIN_MESSAGE_FRAME));
+	 fprintf(stdout, "%s", getResourceString(DBT_MAIN_MESSAGE_FRAME));
        }
        else if(operation && !strcmp(operation, "topframepaint")) {
 	 FILE *html = open_html_file(MY_PAGE);
@@ -1606,11 +1632,11 @@ int main(int argc, char *argv[])
 	 }
        }
        else if(operation && !strcmp(operation, "framepaint")) {
-	 fprintf(stdout, getResourceString(DBT_MAIN_FRAMESET_HEADER));
+	 fprintf(stdout, "%s", getResourceString(DBT_MAIN_FRAMESET_HEADER));
 	 fprintf(stdout, "%s", view ? viewparam : "");
-	 fprintf(stdout, getResourceString(DBT_MAIN_FRAMESET_BODY));
+	 fprintf(stdout, "%s", getResourceString(DBT_MAIN_FRAMESET_BODY));
 	 fprintf(stdout, "%s", view ? viewparam : "");
-	 fprintf(stdout, getResourceString(DBT_MAIN_FRAMESET_FOOTER));
+	 fprintf(stdout, "%s", getResourceString(DBT_MAIN_FRAMESET_FOOTER));
        }
        else if(operation && !strcmp(operation, "viewselect")) {
 	 /*
@@ -1636,7 +1662,7 @@ int main(int argc, char *argv[])
 	 if(server)
 	   selections = get_all_users_views(server, binddn, ldapInfo);
 
-	 fprintf(stdout, getResourceString(DBT_MAIN_BODY_HEADER));
+	 fprintf(stdout, "%s", getResourceString(DBT_MAIN_BODY_HEADER));
 
 	 found=0;
 	 i=0;
@@ -1658,7 +1684,7 @@ int main(int argc, char *argv[])
 
 
 
-	 fprintf(stdout, getResourceString(DBT_MAIN_BODY_FOOTER));
+	 fprintf(stdout, "%s", getResourceString(DBT_MAIN_BODY_FOOTER));
        }
        else {
 
@@ -1741,10 +1767,10 @@ int main(int argc, char *argv[])
 	       count++;
 	     }
 	     if(count == max_count) {
-	       fprintf(stdout, getResourceString(DBT_MAIN_TOPOLOGY_BODY_HEADER));
-	       fprintf(stdout, getResourceString(DBT_STOP_SERVER_ERROR));
-	       fprintf(stdout, getResourceString(DBT_MAIN_TOPOLOGY_BODY_FOOTER));
-	       fprintf(stdout, getResourceString(DBT_MAIN_PAGE_FOOTER));
+	       fprintf(stdout, "%s", getResourceString(DBT_MAIN_TOPOLOGY_BODY_HEADER));
+	       fprintf(stdout, "%s", getResourceString(DBT_STOP_SERVER_ERROR));
+	       fprintf(stdout, "%s", getResourceString(DBT_MAIN_TOPOLOGY_BODY_FOOTER));
+	       fprintf(stdout, "%s", getResourceString(DBT_MAIN_PAGE_FOOTER));
 	       return 1;
 	     }
 	   }
@@ -1757,10 +1783,10 @@ int main(int argc, char *argv[])
 	       count++;
 	     }
 	     if(count == max_count) {
-	       fprintf(stdout, getResourceString(DBT_MAIN_TOPOLOGY_BODY_HEADER));
-	       fprintf(stdout, getResourceString(DBT_START_SERVER_ERROR));
-	       fprintf(stdout, getResourceString(DBT_MAIN_TOPOLOGY_BODY_FOOTER));
-	       fprintf(stdout, getResourceString(DBT_MAIN_PAGE_FOOTER));
+	       fprintf(stdout, "%s", getResourceString(DBT_MAIN_TOPOLOGY_BODY_HEADER));
+	       fprintf(stdout, "%s", getResourceString(DBT_START_SERVER_ERROR));
+	       fprintf(stdout, "%s", getResourceString(DBT_MAIN_TOPOLOGY_BODY_FOOTER));
+	       fprintf(stdout, "%s", getResourceString(DBT_MAIN_PAGE_FOOTER));
 	       return 1;
 	     }
 	   }
@@ -1769,7 +1795,7 @@ int main(int argc, char *argv[])
 
 
 output_topology:
-         fprintf(stdout, getResourceString(DBT_MAIN_TOPOLOGY_BODY_HEADER));
+         fprintf(stdout, "%s", getResourceString(DBT_MAIN_TOPOLOGY_BODY_HEADER));
 
 	 rv = output_topology(ldapInfo,
 			      binddn,
@@ -1777,13 +1803,13 @@ output_topology:
 			      view);
 
 	 if(rv == -1) {
-	   fprintf(stdout, getResourceString(DBT_MAIN_LDAP_ERROR));
+	   fprintf(stdout, "%s", getResourceString(DBT_MAIN_LDAP_ERROR));
 	 }
 
-	 fprintf(stdout, getResourceString(DBT_MAIN_TOPOLOGY_BODY_FOOTER));
+	 fprintf(stdout, "%s", getResourceString(DBT_MAIN_TOPOLOGY_BODY_FOOTER));
        }
 
-       fprintf(stdout, getResourceString(DBT_MAIN_PAGE_FOOTER));
+       fprintf(stdout, "%s", getResourceString(DBT_MAIN_PAGE_FOOTER));
     }
     return 0;
 }
