@@ -59,16 +59,13 @@ int main(int argc, char *argv[])
   char *m;
 
   char *qs = getenv("QUERY_STRING");
-  PRHostEnt   hent;
-  char        buf[PR_NETDB_BUF_SIZE];
   PRStatus    err;
   char        gifbuf[BUFSIZ];
   PRInt32     bytes;
 
   PRFileDesc *req_socket= NULL;
-  int retcode;
-  PRNetAddr netAddr;
-
+  int retcode = 0;
+  PRNetAddr *netaddr = NULL;
   char *result;
   char *host;
   int port;
@@ -79,13 +76,6 @@ int main(int argc, char *argv[])
   struct PRFileInfo64 prfileinfo;
 
   m = getenv("REQUEST_METHOD");
-  /*
-    {
-    int d=1;
-    while(d>0)
-    {;}
-    }
-  */
 
   if(!strcmp(m, "GET")) {
     if(qs)
@@ -93,54 +83,68 @@ int main(int argc, char *argv[])
 
     result = get_cgi_var("result", NULL, NULL);
     host = get_cgi_var("host", NULL, NULL);
-	portstr = get_cgi_var("port", NULL, NULL);
-	if (portstr) {
-		port = atoi(portstr);
-	} else {
-		port = 0;
-	}
+    portstr = get_cgi_var("port", NULL, NULL);
+    if (portstr) {
+        port = atoi(portstr);
+    } else {
+        port = 0;
+    }
 
     if(result && !strcmp(result, "text"))
       fprintf(stdout, "Content-type: text/html\n");
     else
       fprintf(stdout, "Content-type: image/gif\n");
 
-	if (!host || !port) {
-	rpt_err(APP_ERROR, "Invalid hostname and/or port number!", NULL, NULL);
-	}
-    if(!isdigit(host[0]))  {
-      err = PR_GetHostByName(host, buf, sizeof(buf), &hent);
-      if(err == PR_FAILURE) {
-	rpt_err(APP_ERROR, "Cannot resolve host name!", NULL, NULL);
-      }
-
-      PR_InitializeNetAddr(PR_IpAddrNull, (PRUint16)port, &netAddr);
-      memcpy((void *) &netAddr.inet.ip, (void const *) hent.h_addr_list[0], sizeof(netAddr.inet.ip));
+    if (!host || !port) {
+      rpt_err(APP_ERROR, "Invalid hostname and/or port number!", NULL, NULL);
+      return -1;
+    }
+    netaddr = (PRNetAddr *)calloc(1, sizeof(PRNetAddr));
+    if (NULL == netaddr) {
+      rpt_err(APP_ERROR, "Failed to allocate PRNetAddr", NULL, NULL);
+      return -1;
+    }
+    err = PR_StringToNetAddr(host, netaddr);
+    if (PR_SUCCESS == err) {
+      PR_InitializeNetAddr(PR_IpAddrNull, (PRUint16)port, netaddr);
     } else {
-      PR_InitializeNetAddr(PR_IpAddrNull, (PRUint16)port, &netAddr);
-      err = PR_StringToNetAddr(host, &netAddr);
-      if(err == PR_FAILURE) {
-        rpt_err(APP_ERROR, "Cannot parse host address!", NULL, NULL);
+      PRAddrInfo *infop = PR_GetAddrInfoByName(host,
+                            PR_AF_UNSPEC, (PR_AI_ADDRCONFIG|PR_AI_NOCANONNAME));
+      if (infop) {
+        void *iter = NULL;
+        memset( netaddr, 0, sizeof( PRNetAddr ));
+        /* need just one address */
+        iter = PR_EnumerateAddrInfo(iter, infop, (PRUint16)port, netaddr);
+        if (NULL == iter) {
+           rpt_err(APP_ERROR, "Failed to enumerate addrinfo", NULL, NULL);
+           retcode = -1;
+        }
+        PR_FreeAddrInfo(infop);
+      } else {
+        rpt_err(APP_ERROR, "Failed to get addrinfo", NULL, NULL);
+        retcode = -1;
       }
     }
 
-    req_socket = PR_NewTCPSocket();
-      
-    retcode = PR_Connect(req_socket, &netAddr, 10000);
+    if (retcode > -1) {
+      req_socket = PR_NewTCPSocket();
+      retcode = PR_Connect(req_socket, netaddr, 10000);
+    }
+    free(netaddr);
 
     if (retcode != 0) {
       /* SERVER IS DOWN - output the OFF button */
       if(result && !strcmp(result, "text")) {
-	rpt_success("The server is DOWN.");
-	return 1;
+        rpt_success("The server is DOWN.");
+        return 1;
       }
       file = PR_smprintf("%s/togoff.gif", ICONDIR);
     }
     else {
       /* SERVER IS RUNNING - output of ON button */
       if(result && !strcmp(result, "text")) {
-	rpt_success("The server is UP.");
-	return 1;
+        rpt_success("The server is UP.");
+        return 1;
       }
       file = PR_smprintf("%s/togon.gif", ICONDIR);
     }
