@@ -120,7 +120,7 @@ int main(int argc, char *argv[])
     }
     else {
       if(return_format && !strcmp(return_format, "html")) {
-	fprintf(stdout, getResourceString(DBT_UNIX_STOP_FAIL));
+	fprintf(stdout, "%s", getResourceString(DBT_UNIX_STOP_FAIL));
       }
       else {
 	rpt_err(SYSTEM_ERROR,
@@ -170,7 +170,7 @@ int main(int argc, char *argv[])
     }
     else {
       if(return_format && !strcmp(return_format, "html")) {
-	fprintf(stdout, getResourceString(DBT_UNIX_STOP_SUCCESS));
+	fprintf(stdout, "%s", getResourceString(DBT_UNIX_STOP_SUCCESS));
       }
       else {
 	rpt_unknown("Admin server should be shutdown on user request");
