@@ -446,9 +446,9 @@ int main(int argc, char *argv[])
     while(next_html_line(html, line))  {
         if(parse_line(line, NULL))  {
             if(directive_is(line, "SHOW_DATA"))  {
-	      fprintf(stdout, getResourceString(DBT_MAIN_TABLE_HEADER));
+	      fprintf(stdout, "%s", getResourceString(DBT_MAIN_TABLE_HEADER));
 	      output_data(server, sie);
-	      fprintf(stdout, getResourceString(DBT_MAIN_TABLE_FOOTER));
+	      fprintf(stdout, "%s", getResourceString(DBT_MAIN_TABLE_FOOTER));
             } 
             else if(directive_is(line, "ID_TITLE"))  {
 	      char **vals;
