@@ -192,7 +192,7 @@ void display_logfiles(char *logdir, char *default_logfile)
         token = strtok(NULL, seps);
       }
     }
-    fprintf(stdout, getResourceString(DBT_DISPLAY_LOGFILE_SELECT_BEGIN));
+    fprintf(stdout, "%s", getResourceString(DBT_DISPLAY_LOGFILE_SELECT_BEGIN));
 
     logfiles = list_directory(logdir, 0);
       
@@ -209,9 +209,9 @@ void display_logfiles(char *logdir, char *default_logfile)
     }
 
     if(!at_least_one)
-      fprintf(stdout, getResourceString(DBT_DISPLAY_LOGFILE_NO_LOG));
+      fprintf(stdout, "%s", getResourceString(DBT_DISPLAY_LOGFILE_NO_LOG));
 
-    fprintf(stdout, getResourceString(DBT_DISPLAY_LOGFILE_SELECT_END));
+    fprintf(stdout, "%s", getResourceString(DBT_DISPLAY_LOGFILE_SELECT_END));
 
 }
 
@@ -458,19 +458,19 @@ int main(int argc, char *argv[])
 
                     PR_snprintf(full_path, sizeof(full_path), "%s%c%s", logdir, FILE_PATHSEP, file);
                     cmd = fopen(full_path, "r");
-                    fprintf(stdout, getResourceString(DBT_MAIN_WIDTH));
+                    fprintf(stdout, "%s", getResourceString(DBT_MAIN_WIDTH));
                     PR_snprintf(tmp, sizeof(tmp), getResourceString(DBT_SUBTITLE), num, file, (str)? getResourceString(DBT_WITH) : "",
                         (str)? str : "");
 
                     fprintf(stdout, (const char*)getResourceString(DBT_MAIN_TABLE), tmp);
 
-                    fprintf(stdout, getResourceString(DBT_MAIN_TABLE_FONT));
+                    fprintf(stdout, "%s", getResourceString(DBT_MAIN_TABLE_FONT));
                     /* begin search */
                     if(cmd) {
                         search_file(cmd, atoi(num), str);
                         fclose(cmd);
                     }
-                    fprintf(stdout, getResourceString(DBT_MAIN_TABLE_FONT_CLOSE));
+                    fprintf(stdout, "%s", getResourceString(DBT_MAIN_TABLE_FONT_CLOSE));
                 } else {
                     fputs(line, stdout);
                 }
